#
# spec file for package ft2demos
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global freetype_version 2.13.2
Name:           ft2demos
Version:        2.13.2
Release:        2.3
Summary:        Freetype2 Utilities and Demo Programs
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/Other
URL:            https://www.freetype.org
Source0:        https://downloads.sourceforge.net/project/freetype/freetype2/%{version}/freetype-%{version}.tar.xz
Source1:        https://downloads.sourceforge.net/project/freetype/freetype-demos/%{version}/ft2demos-%{version}.tar.xz
Source10:       https://downloads.sourceforge.net/project/freetype/freetype2/%{version}/freetype-%{version}.tar.xz.sig
Source11:       https://downloads.sourceforge.net/project/freetype/freetype-demos/%{version}/ft2demos-%{version}.tar.xz.sig
Source12:       freetype2.keyring
Source1000:     bnc628213_test.otf
Source1004:     bnc629447_sigsegv31.ttf
Source1013:     bnc633938_badbdf.0
Source1015:     bug-641580_CVE-2010-3311.cff
Source1016:     bug-647375_tt2.ttf
# silence our clamav check
NoSource:       1000
# PATCH-FIX-UPSTREAM overflow.patch -- I: Statement is overflowing a buffer
Patch201:       overflow.patch
# PATCH-FIX-OPENSUSE don-t-mark-libpng-as-required-library.patch -- it is private in .pc
Patch202:       don-t-mark-libpng-as-required-library.patch
Patch308961:    bugzilla-308961-cmex-workaround.patch
BuildRequires:  cmake
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(libbrotlidec)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
Requires:       ftbench = %{version}-%{release}
Requires:       ftdiff = %{version}-%{release}
Requires:       ftdump = %{version}
Requires:       ftgamma = %{version}-%{release}
Requires:       ftgrid = %{version}-%{release}
Requires:       ftinspect = %{version}-%{release}
Requires:       ftlint = %{version}-%{release}
Requires:       ftmulti = %{version}-%{release}
Requires:       ftstring = %{version}-%{release}
Requires:       ftvalid = %{version}-%{release}
Requires:       ftview = %{version}-%{release}
Conflicts:      dtc < 1.4.0

%description
Freetype2 utilities and demo programs.

%package -n ftbench
Summary:        Run FreeType benchmarks
Group:          Productivity/Publishing/Other
Conflicts:      %{name} < %{version}-%{release}

%description -n ftbench
Run FreeType benchmarks
This tool is part of the FreeType project

%package -n ftdiff
Summary:        Compare font hinting modes
Group:          Productivity/Publishing/Other
Conflicts:      %{name} < %{version}-%{release}

%description -n ftdiff
Compare font hinting modes
This tool is part of the FreeType project

%package -n ftgamma
Summary:        Screen gamma calibration helper
Group:          Productivity/Publishing/Other
Conflicts:      %{name} < %{version}-%{release}

%description -n ftgamma
Screen gamma calibration helper
This tool is part of the FreeType project

%package -n ftgrid
Summary:        Simple glyph grid viewer
Group:          Productivity/Publishing/Other
Conflicts:      %{name} < %{version}-%{release}

%description -n ftgrid
Simple glyph grid viewer
This tool is part of the FreeType project

%package -n ftinspect
Summary:        Shows how a font gets rendered by FreeType
Group:          Productivity/Publishing/Other
Conflicts:      %{name} < %{version}-%{release}

%description -n ftinspect
Shows how a font gets rendered by FreeType, allowing
control over virtually all rendering parameters
This tool is part of the FreeType project

%package -n ftlint
Summary:        Simple font tester
Group:          Productivity/Publishing/Other
Conflicts:      %{name} < %{version}-%{release}

%description -n ftlint
Simple font tester
This tool is part of the FreeType project

%package -n ftmulti
Summary:        Multiple masters font viewer
Group:          Productivity/Publishing/Other
Conflicts:      %{name} < %{version}-%{release}

%description -n ftmulti
Multiple masters font viewer
This tool is part of the FreeType project

%package -n ftsdf
Summary:        Signed Distance Fields viewer
Group:          Productivity/Publishing/Other
Conflicts:      %{name} < %{version}-%{release}

%description -n ftsdf
Signed Distance Fields viewer
This tool is part of the FreeType project

%package -n ftstring
Summary:        String viewer
Group:          Productivity/Publishing/Other
Conflicts:      %{name} < %{version}-%{release}

%description -n ftstring
String viewer
This tool is part of the FreeType project

%package -n ftvalid
Summary:        Layout table validator
Group:          Productivity/Publishing/Other
Conflicts:      %{name} < %{version}-%{release}

%description -n ftvalid
Layout table validator
This tool is part of the FreeType project

%package -n ftview
Summary:        Simple glyph viewer
Group:          Productivity/Publishing/Other
Conflicts:      %{name} < %{version}-%{release}

%description -n ftview
Simple glyph viewer
This tool is part of the FreeType project

%prep

%setup -q -n freetype-%{freetype_version} -b 1
%patch -P 308961 -p 1
pushd ../ft2demos-%{version}
%patch -P 201 -p1
popd
%patch -P 202 -p1

%build
export CFLAGS="%{optflags} -std=gnu99 -D_GNU_SOURCE $(getconf LFS_CFLAGS)"
%configure \
    --enable-static \
    --without-bzip2

%make_build
pushd ..
    ln -s freetype-%{freetype_version} freetype
    cd ft2demos-%{version}
    %make_build

    cd src/ftinspect
    %cmake
    %cmake_build
popd

%install
mkdir -p %{buildroot}%{_bindir}
pushd ../ft2demos-%{version}/bin/.libs
    # packaged in freetype2.spec
    rm ftdump
    install -m 755 ft* %{buildroot}%{_bindir}
    cd ../../src/ftinspect
    install -m 755 ../../src/ftinspect/build/ftinspect %{buildroot}%{_bindir}
popd

%check
%{buildroot}%{_bindir}/ftbench -c 1 %{SOURCE1000}
%{buildroot}%{_bindir}/ftbench -c 1 %{SOURCE1004} |& grep -v "couldn't load font resource" && echo "should fail"
%{buildroot}%{_bindir}/ftbench -c 1 %{SOURCE1013} |& grep -v "couldn't load font resource" && echo "should fail"
%{buildroot}%{_bindir}/ftbench -c 1 %{SOURCE1015} |& grep -v "couldn't load font resource" && echo "should fail"
%{buildroot}%{_bindir}/ftbench -c 1 %{SOURCE1016}

%files
%doc README

%files -n ftbench
%{_bindir}/ftbench

%files -n ftdiff
%{_bindir}/ftdiff

%files -n ftgamma
%{_bindir}/ftgamma

%files -n ftgrid
%{_bindir}/ftgrid

%files -n ftinspect
%{_bindir}/ftinspect

%files -n ftlint
%{_bindir}/ftlint

%files -n ftmulti
%{_bindir}/ftmulti

%files -n ftsdf
%{_bindir}/ftsdf

%files -n ftstring
%{_bindir}/ftstring

%files -n ftvalid
%{_bindir}/ftvalid

%files -n ftview
%{_bindir}/ftview

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Oct 11 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.13.2:
  - Better support for CFF2 variation fonts.
  - TrueType interpreter  version 38 (also known  as 'Infinality')
    has been removed.
  - Improved OpenVMS support.
* Sat Jul 15 2023 Dirk Müller <dmueller@suse.com>
- update to 2.13.1:
  * `ftbench` has a new  command-line option  `-a`  to
    apply design coordinates.
  * `ftview` can now flip SVG rendering on and off using the
    'Z' key.
  * `ftmulti` it  is  now possible  to toggle  the  fill
    rule  and overlap flag  used for  rendering glyphs using  the 'F3'
    and 'F4' keys,  respectively. Toggling the anti-aliased  mode
    has been changed to the 'TAB' key.
* Thu May  4 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add _multibuild to define 2nd spec file as additional flavor.
  Eliminates the need for source package links in OBS.
* Wed Mar  8 2023 Dirk Müller <dmueller@suse.com>
- update to 2.13.0:
  * The demo program `ftinspect` has  been completely updated and much
    enhanced.  It now  combines the functionality of  almost all other
    graphical FreeType  demo programs into a  single application based
    on the Qt framework.  This was Charlie Jiang's GSoC 2022 project.
  * The `ftbench` demo  program got a new command line  option `-e` to
    set a charmap index.
  * Specifying  a point  size is  now optional  for the  demo programs
    `ftgrid`, `ftmulti`,  `ftstring`, and  `ftview`.  If not  given, a
    default size is used.
  * For  `ftgrid`,  `ftstring`, and  `ftview`,  option  `-e` now  also
    accepts a numeric value to set a charmap index.
  * In  `ftstring`, it  is  now  possible to  set  the displayed  text
    interactively by pressing the 'Enter' key.
  * `ftmulti` can now handle up to 16 design axes.
- drop CVE-2022-31782.patch (upstream)
* Tue Aug 23 2022 Fridrich Strba <fstrba@suse.com>
- Add CVE-2022-31782.patch
  * Fix bsc#1200264, CVE-2022-31782: heap-based buffer overflow in
    ftbench.c
* Fri Aug 12 2022 Stephan Kulow <coolo@suse.com>
- Move ftpdump from ft2demos to freetype - it's required by other
  packages and doesn't require any of the toolkits, so move its
  build early
* Mon May  2 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 2.12.1:
  * Fix clang++ warnings.
  * [ftsdf] Fix segmentation fault.
  * Replace header macros with file names.
  * [ftview] Handle foreground COLR.
  * (Print_Array): New function.
  * (Print_FontInfo_Dictionary, Print_FontPrivate_Dictionary): New functions.
  * [ftgrid] Minor tweaks.
  * [ftgrid] Implement embedded bitmap toggle.
  * Prototype SVG support.
* Fri Jul 23 2021 Ismail Dönmez <ismail@i10z.com>
- Update to version 2.11.0
  * A new demo program `ftsdf` is available to display Signed Distance
    Fields of glyphs.
  * The `ftlint` demo program has been  extended to do more testing of
    its input.
  * The `ttdebug` demo program didn't show changed point coordinates
    (bug introduced in version 2.10.3).
  * It is now possible to adjust the axis increment for variable fonts
    in the `ftmulti` demo program.
  * It is now possible to change the hinting engine in the `ftstring`
    demo program.
  * The graphical demo programs work better now in native color depth
    on win32 and x11.
* Tue Oct 20 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 2.10.4
  * In  `ftview', custom  LCD  filter values  are  now normalized  and
    balanced.  Unorthodox filters are still available through the `-L'
    command line option.
  * The GUI demo programs can now be resized.
  * Demo programs that accept command  line option `-k' can now handle
    function keys, too.  The  corresponding character codes start with
    0xF1.  As  an example, the  POSIX shell syntax (accepted  by bash,
    ksh, and zsh) -k $'\xF3q' emulates the pressing of function key `F3'
    followed by key `q'.
* Sat May  9 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 2.10.2
  * The `ftbench' demo program has a new test for testing the
    `FT_Glyph_Stroke' functionality.
- Add BR on pkgconfig(libbrotlidec) for ftinspect
* Tue Jul  2 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 2.10.1
  * The `ftmulti' demo program now  supports multiple hidden axes with
    the same name tag.
  * `ftview', `ftstring', and `ftgrid' got  a `-k' command line option
    to emulate a sequence of keystrokes at start-up.
  * `ftview', `ftstring', and `ftgrid' now support screen dumping to a
    PNG file.
  * The bytecode debugger, `ttdebug',  now supports variation TrueType
    fonts; a variation font instance can be selected with the new `-d'
    command line option.
- Add tarball signatures and freetype2.keyring
* Mon Jun 24 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 2.10.0
  * The  `ftdump' demo  program has new options `-c'  and `-C'  to
    display charmaps in compact and detailed format, respectively.
    Option `-V' has been removed.
  * The `ftview', `ftstring', and `ftgrid' demo programs use a new
    command line option `-d' to specify the program window's width,
    height, and color depth.
  * The `ftview' demo program now displays red boxes for zero-width
    glyphs.
  * `ftglyph' has limited support to display fonts with
    color-layered glyphs.This will be improved later on.
  * `ftgrid' can now display bitmap fonts also.
  * The `ttdebug' demo program has a new option `-f' to select a
    member of a TrueType collection (TTC).
  * Other various improvements to the demo programs.
* Thu Feb  7 2019 Marguerite Su <i@marguerite.su>
- Remove "Supplements: fonts-config" to avoid accidentally pulling
  in Qt dependencies on some non-Qt based desktops.(boo#1091109)
  fonts-config is fundamental but ft2demos seldom installs by end users.
  only fonts-config maintainers/debuggers may use ft2demos along to
  debug some issues.
* Wed May  2 2018 idonmez@suse.com
- Update to version 2.9.1
  * No changelog upstream.
* Tue Mar 20 2018 ecsos@opensuse.org
- insert missing bzip2-devel for build in Leap 42.3
* Fri Mar 16 2018 crrodriguez@opensuse.org
- Change xorg-x11-devel --> pkgconfig(x11)
* Tue Jan  9 2018 idonmez@suse.com
- Update to version 2.9
  * The `ftbench' demo program has a new test for opening a new
    face and loading some glyphs.
  * The `ftbench' demo program has a new option `-j' to specify
    the last glyph index to be used in the tests.
  * The `ftgrid' demo program has a new option `-n' to suppress
    display of named instances of variation fonts.
  * The `ttdebug' demo program can now show a stack trace (key `K')
    and switch between hexadecimal and decimal display of integers
    (key `I').
* Mon Sep 18 2017 idonmez@suse.com
- Update to version 2.8.1
  * The ftgrid demo program can now toggle the display of grid lines
    with the G key.
  * The ftgrid demo program can toggle a different set of colors
    (suitable to color-blind people) with the C key.
  * The ftgrid demo program now supports the -e command line option
    to select a cmap.
  * The ftdump demo program has a new command line option -t to
    output the SFNT table list.
* Mon May 15 2017 idonmez@suse.com
- A mode to display  light auto-hinting with sub-pixel positioning
  has been added to `ftdiff'.
* Mon Apr  3 2017 fstrba@suse.com
- Package the tools separately to avoid unnecessary dependencies
  on X11 and/or Qt5 (bsc#1031678)
* Sun Jan  1 2017 idonmez@suse.com
- Update to version 2.7.1
  + The `ftmulti' demo program can now switch engines with key `H'.
  + The `ftstring' demo program can now show some built-in,
    non-latin sample strings (to be selected with the TAB key).
  + The `ftview' demo program can now switch between a font's
    charmaps using the TAB key.
- Remove ftinspect-library.patch, merged upstream.
* Tue Sep 20 2016 idonmez@suse.com
- Also build ftinspect
* Fri Sep  9 2016 develop7@develop7.info
- update to version 2.7:
  + Sync with freetype 2.7
* Fri Jul  8 2016 dimstar@opensuse.org
- Update to version 2.6.4:
  + Sync with freetype 2.6.4.
* Mon Mar 28 2016 idonmez@suse.com
- Update to version 2.6.3
  * The `ftgamma' demo  program has been modernized;  the gamma grid
    display has been moved from `ftview' to this program.
  * It is now possible to  cycle through the available LCD filtering
    modes.
* Sun Nov 29 2015 idonmez@suse.com
- Update to version 2.6.2
  * The ftstring  demo program  now supports  sub-pixel rendering;
    use key l to cycle through the LCD modes.
  * The ftstring  demo program now supports  colour rendering; use
    the space key to cycle through various colour combinations.
  * The graphical demo programs now use a default gamma value of 1.8
    (instead of 1.2).
* Fri Oct 23 2015 stefan.bruens@rwth-aachen.de
- no longer conflict dtc, flattened device tree tools are named
  to no longer clash with ft2demos binaries since dtc 1.4
* Sun Oct  4 2015 baiduzhyi.devel@gmail.com
- Update to version 2.6.1.
* Thu Jun 11 2015 idonmez@suse.com
- Update to version 2.6
  * ftgrid can now display GX and MM fonts.
  * Anti-aliasing rendering  modes can now be  selected (with keys
    F5 and F6).
  * The display of point numbers can be toggled with key `D'.
  * ftdump now display information on MM and GX variation axes.
  * ftmulti can now handle up  to six MM  or GX axes.
- Refresh overflow.patch
* Tue Jun  9 2015 fstrba@suse.com
- Merge with the version 2.5.5 from openSUSE:Factory
- Removed patches:
  * CVE-2014-9656.patch
  * CVE-2014-9657.patch
  * CVE-2014-9658.patch
  * CVE-2014-9659.patch
  * CVE-2014-9660.patch
  * CVE-2014-9661.patch
  * CVE-2014-9662.patch
  * CVE-2014-9663.patch
  * CVE-2014-9664.patch
  * CVE-2014-9665.patch
  * CVE-2014-9666.patch
  * CVE-2014-9667.patch
  * CVE-2014-9668.patch
  * CVE-2014-9669.patch
  * CVE-2014-9670.patch
  * CVE-2014-9671.patch
  * CVE-2014-9672.patch
  * CVE-2014-9673.patch
  * CVE-2014-9674.patch
  * CVE-2014-9675.patch
  - Integrated in the 2.5.5 release
- Modified patches:
  * don-t-mark-libpng-as-required-library.patch
  * bugzilla-308961-cmex-workaround.patch
  * freetype2-subpixel.patch
  * freetype2-bitmap-foundry.patch
  * overflow.patch
  - Adapt to the new version of sources
* Wed Jun  3 2015 fstrba@suse.com
- Modified patch:
  * CVE-2014-9671.patch
  - Adapt the code to correspond to the current git master of
    freetype2 (fixes bsc#933247)
* Fri Apr 10 2015 fstrba@suse.com
- Run spec-cleaner on the spec file.
* Fri Feb 20 2015 nadvornik@suse.com
- fixed vulnerabilities (bnc#916847, bnc#916856, bnc#916857,
  bnc#916858, bnc#916859, bnc#916860, bnc#916861, bnc#916862,
  bnc#916863, bnc#916864, bnc#916865, bnc#916867, bnc#916868,
  bnc#916870, bnc#916871, bnc#916872, bnc#916873, bnc#916874,
  bnc#916879, bnc#916881)
  - CVE-2014-9656.patch
  - CVE-2014-9657.patch
  - CVE-2014-9658.patch
  - CVE-2014-9659.patch
  - CVE-2014-9660.patch
  - CVE-2014-9661.patch
  - CVE-2014-9662.patch
  - CVE-2014-9663.patch
  - CVE-2014-9664.patch
  - CVE-2014-9665.patch
  - CVE-2014-9666.patch
  - CVE-2014-9667.patch
  - CVE-2014-9668.patch
  - CVE-2014-9669.patch
  - CVE-2014-9670.patch
  - CVE-2014-9671.patch
  - CVE-2014-9672.patch
  - CVE-2014-9673.patch
  - CVE-2014-9674.patch
  - CVE-2014-9675.patch
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to version 2.5.5
  * IMPORTANT BUG FIXES
  - Handling of  uncompressed PCF files works again (bug
    introduced in version 2.5.4).
- Drop freetype2-2.5.3-fix-pcf.patch, merged upstream
* Mon Dec  8 2014 hrvoje.senjan@gmail.com
- Update to version 2.5.4
  * IMPORTANT BUG FIXES
  - A variant of vulnerability CVE-2014-2240 was identified
    (cf.  http://savannah.nongnu.org/bugs/?43661) and fixed
    in  the new CFF driver.  All users should upgrade.
  - The new auto-hinter code using HarfBuzz crashed for some
    invalid fonts.
  - Many fixes to better protect against malformed input.
  * IMPORTANT CHANGES
  - Full auto-hinter support of the Devanagari script.
  - Experimental auto-hinter support of the Telugu script.
  - CFF stem darkening behaviour can now be controlled at
    build time using the eight macros
    CFF_CONFIG_OPTION_DARKENING_PARAMETER_{X,Y}{1,2,3,4}    .
  - Some fields in the `FT_Bitmap'  structure have been changed
    from signed to unsigned type, which better reflects
    the actual usage. It is also an additional means to
    protect against malformed input. This change doesn't break
    the ABI; however, it might cause compiler warnings.
  * MISCELLANEOUS
  - Improvements to  the auto-hinter's algorithm to recognize
    stems and local extrema.
  - Function `FT_Get_SubGlyph_Info' always returned an error
    even in case of success.
  - Version  2.5.1 introduced major bugs in the cjk part of
    the auto-hinter, which are now fixed.
  - The `FT_Sfnt_Tag' enumeration values have been changed to
    uppercase,  e.g.  `FT_SFNT_HEAD'. The lowercase variants
    are deprecated. This is for orthogonality with all other
    enumeration (and enumeration-like) values in FreeType.
  - `cmake' now supports builds of FreeType as an OS X framework
    and for iOS.
  - Improved project files for vc2010,
    introducing a property file
  - The documentation generator for the API reference has been
    updated to produce  better HTML code (with proper  CSS).
    At the same time, the documentation got a better structure.
  - The FT_LOAD_BITMAP_CROP flag is obsolete; it is not used
    by any driver.
  - The TrueType DELTAP[123] bytecode instructions now work in
    subpixel hinting mode as described in the ClearType
    whitepaper (i.e., for touched points in the
    non-subpixel direction).
  - Many small improvements to the internal arithmetic routines.
- Rebase don-t-mark-libpng-as-required-library.patch,
  bugzilla-308961-cmex-workaround.patch, freetype2-subpixel.patch,
  freetype2-bitmap-foundry.patch and overflow.patch
- Add freetype2-2.5.3-fix-pcf.patch from upstream to resolve
  http://savannah.nongnu.org/bugs/?43774, "Freetype 2.5.4 does not
  load ungzipped PCF fonts"
* Wed May  7 2014 ro@suse.de
- mark bnc628213_test.otf as NoSource to avoid triggering
  clamav check
* Thu Mar 13 2014 hrvoje.senjan@gmail.com
- Improve don-t-mark-libpng-as-required-library.patch: also handle
  Requires.private case (freetype does not include png headers)
* Sun Mar  9 2014 hrvoje.senjan@gmail.com
- Update to version 2.5.3
  * IMPORTANT BUG FIXES
  - A vulnerability was  identified and fixed in the  new CFF
    driver (cf. http://savannah.nongnu.org/bugs/?41697;  it
    doesn't have a CVE number yet).  All users should upgrade.
  - More  bug  fixes related  to  correct  positioning of
    composite glyphs.
  - Many fixes to better protect against malformed input.
  * IMPORTANT CHANGES
  - FreeType can now use the HarfBuzz library to greatly improve
    the auto-hinting of  fonts that  use OpenType features:
    Many glyphs that are part  of such features but don't have
    cmap entries are now handled  properly, for  example small
    caps or superscripts. Define the configuration  macro
    FT_CONFIG_OPTION_USE_HARFBUZZ to activate HarfBuzz support.
    You need HarfBuzz version 0.9.19 or newer. Note that HarfBuzz
    depends on  FreeType; this currently causes a chicken-and-egg
    problem  that can be  solved as follows  in case HarfBuzz
    is not yet installed on your system.
    1. Compile  and  install  FreeType without the configuration
    macro FT_CONFIG_OPTION_USE_HARFBUZZ.
    2. Compile and install HarfBuzz.
    3. Define  macro  FT_CONFIG_OPTION_USE_HARFBUZZ, then
    compile and install FreeType again.
    With FreeType's  `configure' script the procedure  boils
    down to configure, build, and install Freetype, then
    configure, compile, and  install  HarfBuzz,  then configure,
    compile,  and  install FreeType again (after executing
    `make distclean').
  - All  libraries FreeType  depends on  are now  checked
    using  the `pkg-config' configuration files  first,
    followed by alternative methods.
  - The  new  value  `auto'  for the  various  `--with-XXX'
    library options   (for   example   `--with-harfbuzz=auto')
    makes   the `configure' script automatically link to the
    libraries it finds. This is now the default.
  - In case FreeType's `configure' script  can't find a
    library, you can  pass environment  variables to  circumvent
    pkg-config,  and those variables  have been  harmonized as
    a consequence  of the changes mentioned above:
    LIBZ           -> removed; use LIBZ_CFLAGS and LIBZ_LIBS
    LIBBZ2         -> removed; use BZIP2_CFLAGS and BZIP2_LIBS
    LIBPNG_LDFLAGS -> LIBPNG_LIBS
    `./configure --help' shows all available environment variables.
  - The `freetype-config'  script now understands
    option `--static' to emit static linking information.
- Due to buildsystem changes, rename and rebase
  don-t-mark-libpng-as-required-library-in-freetype-co.patch to
  don-t-mark-libpng-as-required-library.patch
* Thu Dec 12 2013 hrvoje.senjan@gmail.com
- Added patches:
  * don-t-mark-libpng-as-required-library-in-freetype-co.patch: it's
    private in pkgconfig file, and causes issues in downstream
    packages
- As per patch, remove libpng-devel Requires from devel package
* Wed Dec 11 2013 arvidjaar@gmail.com
- freetype2 pkgconfig now includes -lpng16; make sure freetype2-devel
  Requires libpng-devel
* Tue Dec 10 2013 hrvoje.senjan@gmail.com
- Update to version 2.5.2
  * Fixed bug  that made  FreeType crash  on some  popular (but  not
    fully conformant) fonts like `ahronbd.ttf'
  * Another round of improvements to correct positioning and hinting
    of composite glyphs in TrueType fonts
  * Fixed bug introduced in version  2.5.1: handling embedded
    bitmap strikes of  TrueType fonts, caused garbage display
    under some circumstances
  * Fixed `ftgrid' demo program compilation in non-development
    builds
- Droped fix-compile-in-non-debug.patch, included in this release
* Wed Nov 27 2013 hrvoje.senjan@gmail.com
- Update to version 2.5.1
  * For  some WinFNT  files,  the last  glyph  wasn't displayed  but
    incorrectly marked as invalid.
  * The vertical size of glyphs was  incorrectly set after a call to
    `FT_GlyphSlot_Embolden', resulting in clipped glyphs.
  * Many fields of the `PCLT' table in SFNT based fonts (if accessed
    with `FT_Get_Sfnt_Table') were computed incorrectly.
  * In TrueType fonts,  hinting of composite glyphs  could sometimes
    deliver  incorrect positions  of  components or  even  distorted
    shapes.
  * WOFF font format support has been added.
  * The auto-hinter now supports Hebrew.  Greek and Cyrillic support
    has been improved.
  * Support for the forthcoming `OS/2'  SFNT table version 5, as can
    be found e.g. in the `Sitka' font family for Windows 8.1.
  * The header  file layout  has been changed.   After installation,
    all files are now located in `<prefix>/include/freetype2'.
    Applications  that  use   (a)  `freetype-config'  or  FreeType's
    `pkg-config' file to get the include directory for the compiler,
    and (b) the documented way for header inclusion like
    [#]include <ft2build.h> or #include FT_FREETYPE_H
    don't need any change to the source code.
  * The stem  darkening feature  of the  new CFF  engine can  now be
    fine-tuned with the new `darkening-parameters' property.
  * `ftgrid' has been updated to toggle various engines with the `H'
    key, similar to `ftview' and `ftdiff'.
  * The functionality of `ttdebug' has been greatly enhanced.
  . It now displays twilight, storage, and control value data; key
  * Better support of ARMv7 and x86_64 processors.
  * Apple's `sbix' color bitmap format is now supported.
  * Improved   auto-hinter  rendering   for  many   TrueType  fonts,
    especially in the range 20-40ppem.
  * A  new face  flag  `FT_FACE_FLAG_COLOR' has  been  added (to  be
    accessed with the macro `FT_HAS_COLOR').
  * `FT_Gzip_Uncompress'   (modeled    after   zlib's   `uncompress'
    function)  has been  added; this  is a  by-product of  the newly
    added WOFF support.
  * Support for  a build with  `cmake' has been contributed  by John
    Cary <cary@txcorp.com>.
  * Support for x64  builds with Visual C++ has  been contributed by
    Kenneth Miller <kennethadammiller@yahoo.com>
  * Manual pages for most demo programs have been added.
  * The GETINFO bytecode instruction for TrueType fonts was buggy if
    used to retrieve subpixel hinting information.  It was necessary
    to set  selector bit 6  to get  results for selector  bits 7-10,
    which is wrong.
  * Improved computation  of emulated vertical metrics  for TrueType
    fonts.
  * Fixed horizontal start-up position of vertical phantom points in
    TrueType bytecode.
- Rebase freetype2-subpixel.patch to current release
- Added fix-compile-in-non-debug.patch, fixes release build of ftdemos
- Added overflow.patch for resolving post-build-check detected error:
  I: Statement is overflowing a buffer
* Wed Jul  3 2013 idonmez@suse.com
- Update to version 2.5.0
  * ftview has been updated to  support color embedded bitmaps.
  * The 'ttdebug' program has been further improved.  In particular,
    it accepts a new command line  option `-H' to select the hinting
    engine.
* Wed Jun 12 2013 werner@suse.com
- Add conflict to package dtc for /usr/bin/ftdump as the two tools
  are different,
  dtc:      ftdump -- Flat Tree dumping utility
  ft2demos: ftdump -- Simple font dumper
* Fri May 10 2013 idonmez@suse.com
- Update to version 2.4.12
  * Using the `H'  key, it is now possible to  select the CFF engine
    in both ftview and ftdiff.
  * The new command line option '-H' for `ftbench' selects the Adobe
    CFF engine.
  * It is  now possible  to directly select  the LCD  rendering mode
    with the keys 'A'-'F' in  'ftview'.  The key mapping for cycling
    through LCD modes  has been changed from 'K' and  'L' to 'k' and
    'l', and  toggling custom LCD  filtering is no longer  mapped to
    key 'F' but to key 'L'.
  * In `ftdiff',  key 'x' toggles  between layout modes:  Either use
    the  advance width  (this is  new and  now the  default) or  the
    bounding box information to determine line breaks.
  * For all demo  tools, the new command line option  `-v' shows the
    version.
  * For the demo tools with a GUI, the new command line options '-w'
    and '-h' select  the width and the height of  the output window,
    respectively.
- Drop ft2demos-build-testname.patch, not needed.
* Fri Jan 11 2013 jw@suse.com
- Rediffed patches.
- CVE-2012-5668.patch, CVE-2012-5669.patch, CVE-2012-5670.patch nothing to do.
* Thu Dec 20 2012 idonmez@suse.com
- Update to version 2.4.11
  * ftdiff now supports UTF-8 encoded input files for option `-f'.
  * Using keys `r' and `R', you can now adjust the stroker radius in
    ftview.
* Sun Jun 17 2012 idonmez@suse.com
- Update to version 2.4.10
  * In the `ftview' demo program, key `e' has been replaced with `x'
    and `y' to  embolden in  the horizontal and  vertical direction,
    respectively.
* Thu Mar  8 2012 idonmez@suse.com
- Update to version 2.4.9
  * The  demo  programs  no  longer  recognize  and  handle  default
    suffixes; you now have to always specify the complete font name.
  * Better rendering and LCD mode cycling added to ftview.
* Tue Feb 14 2012 saschpe@suse.de
- Ran spec-cleaner
* Tue Nov 15 2011 idonmez@suse.com
- Update to version 2.4.8
  * No changes since 2.4.5
* Tue Oct 18 2011 idonmez@suse.com
- Update to version 2.4.7
  * No changes since 2.4.5
* Fri Jul 29 2011 idonmez@novell.com
- Update to version 2.4.6
  * No changes since 2.4.5
* Fri Jul 22 2011 ke@suse.de
- added bnc704612_othersubr.diff, CVE-2011-0226, bnc#704612.
* Thu Jul  7 2011 idonmez@novell.com
- Cleanup spec file
- Drop unneeded use_unix.diff
* Sat Jun 25 2011 idonmez@novell.com
- Update to version 2.4.5
  * The `ftgrid' demo program  can now display  autohinter segments,
    to be toggled on and off with key `s'.
* Fri Feb 25 2011 jw@novell.com
- bnc647375: CVE-2010-3814, regression test added.
* Tue Dec  7 2010 jw@novell.com
- Several old patches got lost. Reapplying:
  * added bnc641580_CVE-2010-3311.diff incl. test-case for bnc#641580
  * bnc633943_CVE-2010-3054 nothing to do.
  * bnc633938_CVE-2010-3053 nothing to do.
  * bnc633938_badbdf.0 regression test added.
* Fri Oct 29 2010 fisiu@opensuse.org
- Updated to version 2.4.3:
  + Make `grKey' enum comprehensive for gcc 4.5 compatibility.
  + [ftbench] Add option `-i' to specify first used glyph index.
* Thu Aug 12 2010 jw@novell.com
- bnc#628213: added bnc628213_1797.diff + regression test
- bnc#629447: CVE-2010-2805..8 are already fixed in upstream 2.4.2
- bnc#619562: CVE-2010-2497,2498,2499,2500,2519,2520 dito.
  added sigsegv31.ttf regression test
* Mon Aug  9 2010 tiwai@suse.de
- updated to version 2.4.2:
  Another serious bug in the CFF font module has been found,
  together with more exploitable vulnerabilities in the T42 font
  driver.
* Tue Jul 20 2010 tiwai@suse.de
- updated to version 2.4.1:
  * major version up
  * bytecode interpreter is enabled as default in the upstream
  * doc-reference is redundant, removed
* Wed Mar 31 2010 coolo@novell.com
- update to version 2.3.12:
  brings considerable improvements for b/w rasterizing of hinted
  TrueType fonts at small sizes, see NEWS for more details
* Mon Jul 27 2009 tiwai@suse.de
- updated to version 2.3.9:
  * see URLs below
    http://www.freetype.org/index2.html#release-freetype-2.3.9
    http://sourceforge.net/project/shownotes.php?group_id=3157&release_id=653641
- updated to version 2.3.9:
  * see URLs below
    http://www.freetype.org/index2.html#release-freetype-2.3.9
    http://sourceforge.net/project/shownotes.php?group_id=3157&release_id=667610
- fix builds with older distros
* Thu Apr 16 2009 nadvornik@suse.cz
- fixed integer overflows [bnc#485889] CVE-2009-0946
* Wed Nov  5 2008 mfabian@suse.de
- bnc#441638: use fix from upstream CVS to fix the return value
  of FT_Get_TrueType_Engine_Type (and make it work as documented).
  Thanks to Werner Lemberg for fixing and Krzysztof Kotlenga for
  reporting the issue.
* Mon Aug 18 2008 mfabian@suse.de
- fix uninitialized pointer "FT_STREAM stream" in function
  FT_Open_Face() which made fontforge crash while trying to apply
  a workaround to the sazanami-fonts because fontforge called
  FT_Open_Face() with 0 for the FT_Library argument and
  then freetype crashed in FT_Stream_Free().
* Wed Jul 23 2008 mfabian@suse.de
- update to 2.3.7. Extract from the docs/CHANGES file:
  • If the library was compiled on an i386 platform using gcc, and
    compiler option -O3 was given, `FT_MulFix' sometimes returned
    incorrect results which could have caused problems with
    `FT_Request_Metrics' and `FT_Select_Metrics', returning an
    incorrect descender size.
  • Pure CFFs without subfonts were scaled incorrectly if the font
    matrix was non-standard.  This bug has been introduced in
    version 2.3.6.
  • The `style_name' field in the `FT_FaceRec' structure often
    contained a wrong value for Type 1 fonts.  This misbehaviour
    has been introduced in version 2.3.6 while trying to fix
    another problem.  [Note, however, that this value is
    informative only since the used algorithm to extract it is
    very simplistic.]
  • Two new macros, FT_OUTLINE_SMART_DROPOUTS and
    FT_OUTLINE_EXCLUDE_STUBS, have been introduced.  Together with
    FT_OUTLINE_IGNORE_DROPOUTS (which was ignored previously) it is
    now possible to control the dropout mode of the `raster' module
    (for B&W rasterization), using the `flags' field in the
    `FT_Outline' structure.
  • The TrueType bytecode interpreter now passes the dropout mode to
    the B&W rasterizer.  This greatly increases the output for small
    ppem values of many fonts like `pala.ttf'.
  • A bunch of potential security problems have been found.  All
    users should update.
  • Microsoft Unicode cmaps in TrueType fonts are now always
    preferred over Apple cmaps.  This is not a bug per se, but there
    exist some buggy fonts created for MS which have broken Apple
    cmaps.  This affects only the automatic selection of FreeType;
    it's always possible to manually select an Apple Unicode cmap if
    desired.
  • Many bug fixes to the TrueType bytecode interpreter.
  • Improved Mac support.
  • Subsetted CID-keyed CFFs are now supported correctly.
  • CID-keyed CFFs with subfonts which are scaled in a non-standard
    way are now handled correctly.
  • A call to FT_Open_Face with `face_index' < 0 crashed FreeType if
    the font was a Windows (bitmap) FNT/FON.
  • The new function `FT_Get_CID_Registry_Ordering_Supplement' gives
    access to those fields in a CID-keyed font.  The code has been
    contributed by Derek Clegg.
  • George Williams contributed code to validate the new `MATH'
    OpenType table (within the `otvalid' module).  The `ftvalid'
    demo program has been extended accordingly.
  • An API for cmap 14 support (for Unicode Variant Selectors, UVS)
    has been contributed by George Williams.
  • A new face flag FT_FACE_FLAG_CID_KEYED has been added, together
    with a macro FT_IS_CID_KEYED which evaluates to 1 if the font is
    CID-keyed.
  • Build support for symbian has been contributed.
  • Better WGL4 glyph name support, contributed by Sergey Tolstov.
  • Debugging output of the various FT_TRACEX macros is now sent to
    stderr.
  • The `ftview' demo program now provides artificial slanting too.
  • The `ftvalid' demo program has a new option `-f' to select the
    font index.
- remove patch for bnc#399169 (came from upstream).
* Fri Jun 13 2008 mfabian@suse.de
- bnc#399169: fix multiple vulnerabilities.
* Mon Apr 14 2008 schwab@suse.de
- Make sure config.guess and config.sub exist.
* Thu Oct 18 2007 mfabian@suse.de
- Bugzilla #334565: avoid crash in xpdf caused by a bug in the
  workaround patch for bug #308961
  (fixed by Peng Wu <pwu@novell.com>).
* Mon Oct  8 2007 mfabian@suse.de
- Bugzilla #308961: improve workaround patch for the broken
  underlining in the CMEX fonts
  (again by Peng Wu <pwu@novell.com>).
* Tue Oct  2 2007 mfabian@suse.de
- Bugzilla #308961: add workaround for broken underlining
  when using the CMEX fonts (by Peng Wu <pwu@novell.com>).
* Mon Aug 20 2007 sbrabec@suse.cz
- Commented out NoSource to provide comfortable rebuild.
* Tue Jul  3 2007 mfabian@suse.de
- update to 2.3.5. Extract from the doc/CHANGES file:
  • Some subglyphs in TrueType fonts were handled incorrectly due
  to a missing graphics state reinitialization.
  • Large .Z files  (as distributed with some X11  packages)
    weren't handled correctly, making FreeType increase the heap
    stack in an endless loop.
  • A large number of bugs have been fixed to avoid crashes and
    endless loops with invalid fonts.
  • The two new cache functions  `FTC_ImageCache_LookupScaler' and
    `FTC_SBit_Cache_LookupScaler' have been added to allow lookup of
    glyphs using an  `FTC_Scaler' object;  this makes it possible to
    use fractional pixel sizes in the cache.  The demo programs have
    been updated accordingly to use this feature.
  • A new API  `FT_Get_CMap_Format' has been added to  get the
    cmap format  of a  TrueType font.   This  is useful  in handling
    PDF files. The code has been contributed by Derek Clegg.
  • The  auto-hinter now  produces better output by default for
    non-Latin scripts like Indic.  This was done by using the CJK
    hinting module as the default instead of the Latin one. Thanks
    to Rahul Bhalerao for this suggestion.
  • A new API `FT_Face_CheckTrueTypePatents' has been added to find
    out whether a given TrueType font uses patented bytecode
    instructions.  The `ft2demos' bundle contains a new program
    called `ftpatchk' which demonstrates its usage.
  • A new API `FT_Face_SetUnpatentedHinting' has been added to
    enable or disable the unpatented hinter.
  • Support for Windows FON files in PE format has been contributed
    by Dmitry Timoshkov.
* Mon Jun  4 2007 mfabian@suse.de
-  Bugzilla #275072: (from upstream CVS):
  Check for negative number of points in contours. Problem
  reported by Victor Stinner <victor.stinner@haypocalc.com>.
* Tue May 22 2007 mfabian@suse.de
- fix last patch to avoid crashes when loader->exec == NULL.
  (caused crashes in xpdf, kpdf, acroread for me for many
  .pdf files).
* Tue Apr 10 2007 mfabian@suse.de
- update to 2.3.4. Extract from the doc/CHANGES file:
  • A serious bug in the handling of bitmap fonts (and bitmap
    strikes of outline fonts) has been introduced in 2.3.3.
  • Remove a serious regression in the TrueType bytecode
    interpreter that was introduced in version 2.3.2.  Note that
    this does not disable the improvements introduced to the
    interpreter in version 2.3.2, only some ill cases that occurred
    with certain fonts (though a few popular ones).
  • The auto-hinter now ignores single-point contours for
    computing blue zones.  This bug created `wavy' baselines when
    rendering text with various fonts that use these contours to
    model mark-attach points (these are points that are never
    rasterized and are placed outside of the glyph's real
    outline).
  • The `rsb_delta' and `lsb_delta' glyph slot fields are now set
    to 0 for mono-spaced fonts.  Otherwise code that uses them
    would essentially ruin the fixed-advance property.
  • Fix CVE-2007-1351 which can cause an integer overflow while
    parsing BDF fonts, leading to a potentially exploitable heap
    overflow condition.
  • FreeType returned incorrect kerning information from TrueType
    fonts when the bytecode interpreter was enabled.  This
    happened due to a typo introduced in version 2.3.0.
  • Negative kerning values from PFM files are now reported
    correctly (they were read as 16-bit unsigned values from the
    file).
  • Fixed a small memory leak when `FT_Init_FreeType' failed for
    some reason.
  • The Postscript hinter placed and sized very thin and ghost
    stems incorrectly.
  • The TrueType bytecode interpreter has been fixed to get rid
    of most of the rare differences seen in comparison to the
    Windows font loader.
  • A new demo program `ftdiff' has been added to compare
    TrueType hinting, FreeType's auto hinting, and rendering
    without hinting in three columns.
  • The auto-hinter now better deals with serifs and corner cases
    (e.g., glyph '9' in Arial at 9pt, 96dpi).  It also improves
    spacing adjustments and doesn't change widths for non-spacing
    glyphs.
* Wed Mar 28 2007 mfabian@suse.de
- Bugzilla #258335: fix buffer overflow in handling of bdf fonts.
* Mon Feb  5 2007 mfabian@suse.de
- update to 2.3.1.
  • The TrueType interpreter sometimes returned incorrect
    horizontal metrics due to a bug in the handling of the SHZ
    instruction.
  • A typo  in  a  security  check  introduced  after
    version 2.2.1 prevented FreeType to render some glyphs in CFF
    fonts.
* Sun Jan 21 2007 mfabian@suse.de
- update to 2.3.0 (from rc1 to final release)
* Fri Jan 12 2007 mfabian@suse.de
- update to 2.2.1.20070112 (= 2.3.0rc1).
  • bugzilla #231417 fixed, see ChangeLog:
    2007-01-10  David Turner  <david at freetype.org>
    [...]
  * src/pshinter/pshalgo.c (psh_glyph_compute_inflections):
    fixed a typo which created an endless loop with some malformed
    font files
* Wed Nov 22 2006 mfabian@suse.de
- Bugzilla #222693: disable bugzilla-159166-reduce-embolden-distance.patch
* Thu Nov  9 2006 mfabian@suse.de
- Bugzilla #216793: "local variable used before set"
* Tue Nov  7 2006 mfabian@suse.de
- Bugzilla #217388: fix advance handling in FT_GlyphSlot_Embolden()
* Fri Oct 27 2006 mfabian@suse.de
- Bugzilla #158573: update to 2.2.1.20061027.
* Fri Oct 20 2006 mfabian@suse.de
- disable the recent fixes of the byte code interpreter because
  if breaks the rendering of "Luxi Mono"
  (/usr/share/fonts/truetype/luximr.ttf) See also:
  http://lists.gnu.org/archive/html/freetype/2006-10/msg00034.html
* Fri Oct 13 2006 mfabian@suse.de
- update to 2.2.1.20061013
  • Add support for LCD color filtering to ftview.
* Wed Aug 16 2006 mfabian@suse.de
- use "Supplements: fonts-config" only for SuSE Linux >= 10.1.
* Thu Aug 10 2006 mfabian@suse.de
- Bugzilla #195835: add "Supplements: fonts-config" to .spec file.
* Mon Jul 10 2006 mfabian@suse.de
- Bugzilla #190902: add patch from upstream CVS to handle
  bad PCF files.
* Tue Jun 20 2006 mfabian@suse.de
- update to 2.2.1:
  + remove bugzilla-97202-fix-x-crash.patch
  + remove bugzilla-157441-autofit-cjk-cvs.patch
    (was from upstream CVS).
  + remove bugzilla-158156-memory-leak.patch
    (was from upstream CVS).
  + remove bugzilla-158573-fix-orientation-detection.patch
    (included upstream).
  + remove bugzilla-133086-enable-kerning.patch
    (was from upstream).
  + remove bugzilla-154928-integer-overflows.patch
    (was from upstream).
  + remove bugzilla-159304-fix-ftview-glyph-index.patch
    (fixed upstream).
  + remove enable_ft_optimize_memory.patch (is already enabled by
    default now).
  + adapt bugzilla-159166-reduce-embolden-distance.patch a little
    bit to achieve the same boldness effect as with the last
    package.
* Thu Jun  1 2006 mfabian@suse.de
- Bugzilla #154928: fix several integer overflows.
* Mon Apr 24 2006 mfabian@suse.de
- Bugzilla #133086: enable kerning, see
  http://lists.nongnu.org/archive/html/freetype-devel/2005-09/msg00027.html
* Tue Mar 21 2006 dmueller@suse.de
- build parallel
* Mon Mar 20 2006 zsu@suse.de
- Bugzilla #158573: fix corrupt embolden glyphs issue for CJK fonts.
- Bugzilla #159166: reduce embolden strength to get better rendering
  effect.
- Bugzilla #159304: fix wrong glyph index handling in ftview when
  rendering embolden or outline mode.
* Wed Mar 15 2006 mfabian@suse.de
- Bugzilla #157441:  remove 0x0100-0xFFFF from CJK Unicode range,
  as it might cause side effects for non-CJK scripts.
* Wed Mar 15 2006 mfabian@suse.de
- Bugzilla #158156: fix a memory leak (by Zhe Su <zsu@novell.com>).
* Tue Mar 14 2006 mfabian@suse.de
- Bugzilla #157441: instead of Takashi's patches, use a patch
  from upstream CVS which renders slightly better.
* Tue Mar 14 2006 mfabian@suse.de
- Bugzilla #157441: FZSongTi.ttf contains a lot more (CJK)-glyphs
  than most other fonts, therefore we have to expand the cjk range
  in Takashi Iwai's "ft2-autofit-02-cjk.diff" to render these
  glyphs correctly as well.
- Bugzilla #157441: don't apply ft2-autofit-03-latin-baseline.diff
  as it has some side effects.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 mfabian@suse.de
- Bugzilla #105626: add patches by Takashi IWAI <tiwai@suse.de>
  to improve the autohinting (mainly for CJK fonts).
* Thu Jul 21 2005 mfabian@suse.de
- fix typo in .spec file.
* Wed Jul 20 2005 mfabian@suse.de
- Bugzilla #97202: apply workaround to avoid crashing the Xserver.
  I need to disable FT_OPTIMIZE_MEMORY again to apply that
  workaround.
* Tue Jul 19 2005 mfabian@suse.de
- enable FT_OPTIMIZE_MEMORY.
- enable the byte code interpreter again.
* Tue Jul 12 2005 mfabian@suse.de
- update to 2.1.10.
  + fixes serious bug introduced in 2.1.8 which caused many
    distortions for TrueType fonts
  + amount of heap memory used is drastically reduced
  For more details see /usr/share/doc/packages/freetype2/CHANGES.
- disable freetype-autohint-cjkfonts.patch for the moment, the
  auto-hinter has been replaced with a new module called the
  'auto-fitter' which is "prepared better to support non-latin1
  scripts in next releases". Currently the rendering quality of
  CJK fonts seems to have suffered though compared to 2.1.9
  with the freetype-autohint-cjkfonts.patch.
* Mon Jul  4 2005 meissner@suse.de
- use system zlib.
* Tue Jul  6 2004 mfabian@suse.de
- update to 2.1.9.
* Mon May 10 2004 mfabian@suse.de
- update to 2.1.8.
  remove the bdf-pcf fixes for bitmap font metric issues which
  were backported from CVS, they are included in this release
* Fri Apr 16 2004 mfabian@suse.de
- Bugzilla #38205:
  add patch from http://www.kde.gr.jp/~akito/patch/freetype2/2.1.7
  to improve the hinting results (mainly for CJK fonts).
* Wed Mar 24 2004 mfabian@suse.de
- Add ft2-stream-compat.diff for binary compatibility when
  upgrading from SLES8 to SLES9.
  The FT_Stream functions have been renamed and although these
  functions were declared for internal use only by the freetype
  developers, they have been used in Qt (and possibly elsewhere).
  Therefore, 3rd party which linked statically against Qt might
  not work after upgrading from SLES8 to SLES9.
  Fix this problem with a patch by Kurt Garloff <garloff@suse.de>
  which defines appropriate weak symbols.
* Tue Mar 16 2004 mfabian@suse.de
- fix Bugzilla# 36143: backport fixes for bitmap font metric issues
  from CVS to fix  crashes when using bitmap fonts caused by the
  new libXft-2.1.5 from the X.org tree.
* Mon Mar 15 2004 mfabian@suse.de
- mark freetype2 tarball as Nosource, it is already in the source
  rpm of the main freetype2 package.
* Mon Jan 12 2004 adrian@suse.de
- add %%defattr
* Fri Jan  9 2004 mfabian@suse.de
- add "-fno-strict-aliasing" compile option to prevent crashes
  for example in ftdump and mkfontscale.
* Wed Dec 17 2003 mfabian@suse.de
- update to 2.1.7.
- remove freetype2-type1.patch (included upstream)
* Wed Oct  8 2003 schwab@suse.de
- Fix invalid free.
* Fri Sep 26 2003 mfabian@suse.de
- update to 2.1.5.
- remove freetype-bdf-pcf-drivr.patch, freetype2-bitmap-style.patch
  (included upstream).
- remove gzip-eof.patch.
* Mon Sep  1 2003 mfabian@suse.de
- add gzip-eof.patch to fix the problem that some gzipped bitmap
  fonts could not be opened by freetype2.
  See also:
  http://marc.theaimsgroup.com/?l=freetype-devel&m=105505219505600&w=2
  and followups.
* Tue Aug 26 2003 mfabian@suse.de
- add freetype2-bitmap-style.patch: check the bdf properties
  WEIGHT_NAME and SLANT case insensitively. Without that,
  these properties are not correctly recognized when the fonts
  specify them in lower case.
* Fri May 16 2003 mfabian@suse.de
- don't install files which will not be packaged.
* Tue Apr  8 2003 mfabian@suse.de
- update to 2.1.4
* Fri Apr  4 2003 mfabian@suse.de
- freetype updated to 2.1.4rc2
* Fri Mar  7 2003 mfabian@suse.de
- Bug #24755: further improvement: add " Wide" to the family name
  for fonts which have an average width >= point size, i.e. fonts
  which have glyphs which are at least square (or maybe even
  wider). This makes fonts which contain only double width
  characters (for example the "misc-fixed" 18x18ja.bdf) clearly
  distinct from single width fonts of the same family and
  avoids that they get accidentally selected via freetype2/Xft2.
* Fri Mar  7 2003 mfabian@suse.de
- Bug #24775: partly fixed by a patch to freetype which returns
  "FOUNDRY FAMILY_NAME" as the family_name for bitmap fonts.
  Without that change, all bitmap fonts which have "Fixed"
  in FAMILY_NAME also had the same family_name "Fixed" via
  freetype/Xft2 and it was not possible to distinguish between
  them, therefore the selection of "Fixed" bitmap fonts produced
  quite surprising results. After this change, the fonts show
  up for example as "Misc Fixed", "Etl Fixed", etc. via
  freetype2/Xft2, which makes it easy to select the right one.
* Wed Jan 29 2003 mfabian@suse.de
- add freetype2-bc.patch
* Sat Jan 25 2003 mfabian@suse.de
- use the original names for the utilities, i.e. ftdump
  instead of ft2dump, etc. ... (I renamed the utilities
  in freetype1 to ft1dump, ft1view, etc. ...
* Mon Jan 13 2003 mfabian@suse.de
- new package ft2demos, version 2.1.3
